@@ -2,7 +2,7 @@
 package BerkeleyDB;
 
 
-#     Copyright (c) 1997-2013 Paul Marquess. All rights reserved.
+#     Copyright (c) 1997-9 Paul Marquess. All rights reserved.
 #     This program is free software; you can redistribute it and/or
 #     modify it under the same terms as Perl itself.
 #
@@ -17,7 +17,7 @@ use Carp;
 use vars qw($VERSION @ISA @EXPORT $AUTOLOAD
 		$use_XSLoader);
 
-$VERSION = '0.54';
+$VERSION = '0.60';
 
 require Exporter;
 
@@ -41,6 +41,7 @@ BEGIN {
 @EXPORT = qw(
 	DB2_AM_EXCL
 	DB2_AM_INTEXCL
+	DB2_AM_MPOOL_OPENED
 	DB2_AM_NOWAIT
 	DB_AFTER
 	DB_AGGRESSIVE
@@ -84,6 +85,7 @@ BEGIN {
 	DB_COMPACT_FLAGS
 	DB_CONSUME
 	DB_CONSUME_WAIT
+	DB_CONVERT
 	DB_CREATE
 	DB_CURLSN
 	DB_CURRENT
@@ -159,11 +161,14 @@ BEGIN {
 	DB_ENV_TXN_WRITE_NOSYNC
 	DB_ENV_USER_ALLOC
 	DB_ENV_YIELDCPU
+	DB_EVENT_FAILCHK_PANIC
+	DB_EVENT_MUTEX_DIED
 	DB_EVENT_NOT_HANDLED
 	DB_EVENT_NO_SUCH_EVENT
 	DB_EVENT_PANIC
 	DB_EVENT_REG_ALIVE
 	DB_EVENT_REG_PANIC
+	DB_EVENT_REP_AUTOTAKEOVER
 	DB_EVENT_REP_AUTOTAKEOVER_FAILED
 	DB_EVENT_REP_CLIENT
 	DB_EVENT_REP_CONNECT_BROKEN
@@ -173,6 +178,7 @@ BEGIN {
 	DB_EVENT_REP_ELECTED
 	DB_EVENT_REP_ELECTION_FAILED
 	DB_EVENT_REP_INIT_DONE
+	DB_EVENT_REP_INQUEUE_FULL
 	DB_EVENT_REP_JOIN_FAILURE
 	DB_EVENT_REP_LOCAL_SITE_REMOVED
 	DB_EVENT_REP_MASTER
@@ -185,9 +191,12 @@ BEGIN {
 	DB_EVENT_REP_WOULD_ROLLBACK
 	DB_EVENT_WRITE_FAILED
 	DB_EXCL
+	DB_EXIT_FAILCHK
+	DB_EXIT_FILE_EXISTS
 	DB_EXTENT
 	DB_FAILCHK
 	DB_FAILCHK_ISALIVE
+	DB_FAILURE_SYMPTOM_SIZE
 	DB_FAST_STAT
 	DB_FCNTL_LOCKING
 	DB_FILEOPEN
@@ -197,6 +206,7 @@ BEGIN {
 	DB_FLUSH
 	DB_FORCE
 	DB_FORCESYNC
+	DB_FORCESYNCENV
 	DB_FOREIGN_ABORT
 	DB_FOREIGN_CASCADE
 	DB_FOREIGN_CONFLICT
@@ -306,10 +316,12 @@ BEGIN {
 	DB_LOG_DIRECT
 	DB_LOG_DISK
 	DB_LOG_DSYNC
+	DB_LOG_EXT_FILE
 	DB_LOG_INMEMORY
 	DB_LOG_IN_MEMORY
 	DB_LOG_LOCKED
 	DB_LOG_NOCOPY
+	DB_LOG_NOSYNC
 	DB_LOG_NOT_DURABLE
 	DB_LOG_NO_DATA
 	DB_LOG_PERM
@@ -328,12 +340,17 @@ BEGIN {
 	DB_LOG_ZERO
 	DB_MAX_PAGES
 	DB_MAX_RECORDS
+	DB_MEM_DATABASE
+	DB_MEM_DATABASE_LENGTH
+	DB_MEM_EXTFILE_DATABASE
 	DB_MEM_LOCK
 	DB_MEM_LOCKER
 	DB_MEM_LOCKOBJECT
 	DB_MEM_LOGID
+	DB_MEM_REP_SITE
 	DB_MEM_THREAD
 	DB_MEM_TRANSACTION
+	DB_META_CHKSUM_FAIL
 	DB_MPOOL_CLEAN
 	DB_MPOOL_CREATE
 	DB_MPOOL_DIRTY
@@ -355,8 +372,10 @@ BEGIN {
 	DB_MUTEXDEBUG
 	DB_MUTEXLOCKS
 	DB_MUTEX_ALLOCATED
+	DB_MUTEX_DESCRIBE_STRLEN
 	DB_MUTEX_LOCKED
 	DB_MUTEX_LOGICAL_LOCK
+	DB_MUTEX_OWNER_DEAD
 	DB_MUTEX_PROCESS_ONLY
 	DB_MUTEX_SELF_BLOCK
 	DB_MUTEX_SHARED
@@ -369,6 +388,7 @@ BEGIN {
 	DB_NODUPDATA
 	DB_NOERROR
 	DB_NOFLUSH
+	DB_NOINTMP
 	DB_NOLOCKING
 	DB_NOMMAP
 	DB_NOORDERCHK
@@ -383,6 +403,7 @@ BEGIN {
 	DB_NO_AUTO_COMMIT
 	DB_NO_CHECKPOINT
 	DB_ODDFILESIZE
+	DB_OFF_T_MAX
 	DB_OK_BTREE
 	DB_OK_HASH
 	DB_OK_HEAP
@@ -433,6 +454,7 @@ BEGIN {
 	DB_REGION_ANON
 	DB_REGION_INIT
 	DB_REGION_MAGIC
+	DB_REGION_MAGIC_RECOVER
 	DB_REGION_NAME
 	DB_REGISTER
 	DB_REGISTERED
@@ -447,9 +469,15 @@ BEGIN {
 	DB_REPMGR_ACKS_ONE_PEER
 	DB_REPMGR_ACKS_QUORUM
 	DB_REPMGR_CONF_2SITE_STRICT
+	DB_REPMGR_CONF_DISABLE_POLL
 	DB_REPMGR_CONF_ELECTIONS
+	DB_REPMGR_CONF_ENABLE_EPOLL
+	DB_REPMGR_CONF_FORWARD_WRITES
+	DB_REPMGR_CONF_PREFMAS_CLIENT
+	DB_REPMGR_CONF_PREFMAS_MASTER
 	DB_REPMGR_CONNECTED
 	DB_REPMGR_DISCONNECTED
+	DB_REPMGR_ISELECTABLE
 	DB_REPMGR_ISPEER
 	DB_REPMGR_ISVIEW
 	DB_REPMGR_NEED_RESPONSE
@@ -463,6 +491,7 @@ BEGIN {
 	DB_REP_CONF_AUTOROLLBACK
 	DB_REP_CONF_BULK
 	DB_REP_CONF_DELAYCLIENT
+	DB_REP_CONF_ELECT_LOGLENGTH
 	DB_REP_CONF_INMEM
 	DB_REP_CONF_LEASE
 	DB_REP_CONF_NOAUTOINIT
@@ -482,6 +511,7 @@ BEGIN {
 	DB_REP_HEARTBEAT_SEND
 	DB_REP_HOLDELECTION
 	DB_REP_IGNORE
+	DB_REP_INELECT
 	DB_REP_ISPERM
 	DB_REP_JOIN_FAILURE
 	DB_REP_LEASE_EXPIRED
@@ -502,6 +532,7 @@ BEGIN {
 	DB_REP_STARTUPDONE
 	DB_REP_UNAVAIL
 	DB_REP_WOULDROLLBACK
+	DB_REP_WRITE_FORWARD_TIMEOUT
 	DB_REVSPLITOFF
 	DB_RMW
 	DB_RPCCLIENT
@@ -523,12 +554,15 @@ BEGIN {
 	DB_SET
 	DB_SET_LOCK_TIMEOUT
 	DB_SET_LTE
+	DB_SET_MUTEX_FAILCHK_TIMEOUT
 	DB_SET_RANGE
 	DB_SET_RECNO
 	DB_SET_REG_TIMEOUT
 	DB_SET_TXN_NOW
 	DB_SET_TXN_TIMEOUT
 	DB_SHALLOW_DUP
+	DB_SLICED
+	DB_SLICE_CORRUPT
 	DB_SNAPSHOT
 	DB_SPARE_FLAG
 	DB_STAT_ALL
@@ -557,6 +591,7 @@ BEGIN {
 	DB_SURPRISE_KID
 	DB_SWAPBYTES
 	DB_SYSTEM_MEM
+	DB_SYSTEM_MEM_MISSING
 	DB_TEMPORARY
 	DB_TEST_ELECTINIT
 	DB_TEST_ELECTSEND
@@ -587,6 +622,7 @@ BEGIN {
 	DB_TXN_BACKWARD_ROLL
 	DB_TXN_BULK
 	DB_TXN_CKP
+	DB_TXN_DISPATCH
 	DB_TXN_FAMILY
 	DB_TXN_FORWARD_ROLL
 	DB_TXN_LOCK
@@ -638,6 +674,7 @@ BEGIN {
 	DB_VERB_REP_SYNC
 	DB_VERB_REP_SYSTEM
 	DB_VERB_REP_TEST
+	DB_VERB_SLICE
 	DB_VERB_WAITSFOR
 	DB_VERIFY
 	DB_VERIFY_BAD
@@ -661,6 +698,8 @@ BEGIN {
 	DB_YIELDCPU
 	DB_debug_FLAG
 	DB_user_BEGIN
+	EPOLL
+	HAVE_EPOLL
 	LOGREC_ARG
 	LOGREC_DATA
 	LOGREC_DB
@@ -669,12 +708,15 @@ BEGIN {
 	LOGREC_Done
 	LOGREC_HDR
 	LOGREC_LOCKS
+	LOGREC_LONGARG
 	LOGREC_OP
 	LOGREC_PGDBT
 	LOGREC_PGDDBT
 	LOGREC_PGLIST
 	LOGREC_POINTER
 	LOGREC_TIME
+	POLL
+	SELECT
 	);
 
 sub AUTOLOAD {
@@ -917,6 +959,7 @@ sub new
 					LockDetect     	=> 0,
 					TxMax     	=> 0,
 					LogConfig     	=> 0,
+					LogFileMode   	=> undef,
 					MaxLockers     	=> 0,
 					MaxLocks     	=> 0,
 					MaxObjects     	=> 0,
